@@ -1,6 +1,6 @@
 use crate::{
-	Back, BackMut, Capacity, Clear, Collection, CollectionMut, CollectionRef, Front, FrontMut,
-	Iter, IterMut, Len, PopBack, PushBack, Remove, Reserve, WithCapacity,
+	Capacity, Clear, Collection, CollectionMut, CollectionRef, Get, GetMut, Iter, IterMut, Len,
+	PopBack, PushBack, Remove, Reserve, WithCapacity,
 };
 use smallvec::{Array, SmallVec};
 
@@ -13,6 +13,8 @@ impl<A: Array> CollectionRef for SmallVec<A> {
 	where
 		Self: 'a,
 	= &'a A::Item;
+
+	crate::covariant_item_ref!();
 }
 
 impl<A: Array> CollectionMut for SmallVec<A> {
@@ -20,6 +22,8 @@ impl<A: Array> CollectionMut for SmallVec<A> {
 	where
 		Self: 'a,
 	= &'a mut A::Item;
+
+	crate::covariant_item_mut!();
 }
 
 impl<A: Array> WithCapacity for SmallVec<A> {
@@ -55,31 +59,17 @@ impl<A: Array> Reserve for SmallVec<A> {
 	}
 }
 
-impl<A: Array> Back for SmallVec<A> {
+impl<A: Array> Get<usize> for SmallVec<A> {
 	#[inline(always)]
-	fn back(&self) -> Option<&A::Item> {
-		self.last()
+	fn get(&self, index: usize) -> Option<&A::Item> {
+		self.as_slice().get(index)
 	}
 }
 
-impl<A: Array> BackMut for SmallVec<A> {
+impl<A: Array> GetMut<usize> for SmallVec<A> {
 	#[inline(always)]
-	fn back_mut(&mut self) -> Option<&mut A::Item> {
-		self.last_mut()
-	}
-}
-
-impl<A: Array> Front for SmallVec<A> {
-	#[inline(always)]
-	fn front(&self) -> Option<&A::Item> {
-		self.first()
-	}
-}
-
-impl<A: Array> FrontMut for SmallVec<A> {
-	#[inline(always)]
-	fn front_mut(&mut self) -> Option<&mut A::Item> {
-		self.first_mut()
+	fn get_mut(&mut self, index: usize) -> Option<&mut A::Item> {
+		self.as_mut_slice().get_mut(index)
 	}
 }
 
